@@ -1,5 +1,6 @@
 import json
 import requests
+import logging
 from dateutil.relativedelta import *
 
 from datetime import datetime
@@ -676,7 +677,7 @@ class API(object):
         if response.status_code == requests.codes.ok:
             return json.loads(response.content.decode('utf-8'))
         else:
-            return None
+            return response
 
     ######################
     # Public API methods #
@@ -730,7 +731,7 @@ class API(object):
                                        with_session_token=False)
 
     def login(self):
-        """ Try to login and get a session token. """
+        """ Try to login and get a user token. """
 
         # Setup authentication information (Used only in 8.0)
         login_info = {
@@ -743,6 +744,8 @@ class API(object):
         res = self.__send_post_request(self.__url_login, login_json,
                                        with_user_token=False,
                                        with_session_token=False)
+        logging.info(res)
+
         self.__user_token = res['user_token']
 
     def panel_login(self):
@@ -757,7 +760,7 @@ class API(object):
         }
         
         panel_login_json = json.dumps(panel_login_info, separators=(',', ':'))
-        res = self.__send_post_request(self.__url_login, panel_login_json,
+        res = self.__send_post_request(self.__url_panel_login, panel_login_json,
                                         with_user_token=True,
                                         with_session_token=False)
                                         
